@@ -55,7 +55,7 @@ else:
         return f
 
 
-class _CaptureMethod(Enum):
+class _CaptureMethod(str, Enum):
     FD = "fd"
     NO = "no"
     SYS = "sys"
@@ -68,7 +68,7 @@ def pytask_extend_command_line_interface(cli: click.Group) -> None:
     additional_parameters = [
         click.Option(
             ["--capture"],
-            type=click.Choice([x.value for x in _CaptureMethod]),
+            type=click.Choice(_CaptureMethod),  # type: ignore[arg-type]
             help="Per task capturing method. [dim]\\[default: fd][/]",
         ),
         click.Option(
@@ -78,7 +78,7 @@ def pytask_extend_command_line_interface(cli: click.Group) -> None:
         ),
         click.Option(
             ["--show-capture"],
-            type=click.Choice([x.value for x in ShowCapture]),
+            type=click.Choice(ShowCapture),  # type: ignore[arg-type]
             help=(
                 "Choose which captured output should be shown for failed tasks. "
                 "[dim]\\[default: all][/]"
@@ -122,8 +122,6 @@ def pytask_parse_config(
 @hookimpl
 def pytask_post_parse(config: dict[str, Any]) -> None:
     """Initialize the CaptureManager."""
-    _colorama_workaround()
-
     pluginmanager = config["pm"]
     capman = CaptureManager(config["capture"])
     pluginmanager.register(capman, "capturemanager")
@@ -135,22 +133,6 @@ def pytask_post_parse(config: dict[str, Any]) -> None:
 # Copied from pytest with slightly modified docstrings.
 
 
-def _colorama_workaround() -> None:
-    """Ensure colorama is imported so that it attaches to the correct stdio
-    handles on Windows.
-
-    colorama uses the terminal on import time. So if something does the
-    first import of colorama while I/O capture is active, colorama will
-    fail in various ways.
-
-    """
-    if sys.platform.startswith("win32"):
-        try:
-            import colorama  # noqa: F401
-        except ImportError:
-            pass
-
-
 # IO Helpers.
 
 
@@ -429,8 +411,8 @@ class FDCaptureBinary:
         return res
 
     def done(self) -> None:
-        """Stop capturing, restore streams, return original capture file,
-        seeked to position zero."""
+        """Stop capturing, restore streams, return original capture file, seeked to
+        position zero."""
         self._assert_state("done", ("initialized", "started", "suspended", "done"))
         if self._state == "done":
             return
