@@ -72,18 +72,18 @@ theme = Theme(
     {
         # Statuses
         "failed": "#BF2D2D",
-        "failed.textonly": "#ffffff on #BF2D2D",
+        "failed.textonly": "#f2f2f2 on #BF2D2D",
         "neutral": "",
         "skipped": "#F4C041",
-        "skipped.textonly": "#000000 on #F4C041",
+        "skipped.textonly": "#0c0c0c on #F4C041",
         "success": "#137C39",
-        "success.textonly": "#ffffff on #137C39",
+        "success.textonly": "#f2f2f2 on #137C39",
         "warning": "#F4C041",
         # Help page.
         "command": "bold #137C39",
         "option": "bold #F4C041",
         "switch": "bold #D54523",
-        "metavar": "bold yellow",
+        "metavar": "bold #FFFF00",
     }
 )
 
@@ -172,12 +172,20 @@ def create_url_style_for_task(
     """Create the style to add a link to a task id."""
     url_scheme = _EDITOR_URL_SCHEMES.get(edtior_url_scheme, edtior_url_scheme)
 
-    info = {
-        "path": _get_file(task_function),
-        "line_number": _get_source_lines(task_function),
-    }
+    if not url_scheme:
+        return Style()
 
-    return Style() if not url_scheme else Style(link=url_scheme.format(**info))
+    try:
+        info = {
+            "path": _get_file(task_function),
+            "line_number": _get_source_lines(task_function),
+        }
+    except (OSError, TypeError):
+        style = Style()
+    else:
+        style = Style(link=url_scheme.format(**info))
+
+    return style
 
 
 def create_url_style_for_path(path: Path, edtior_url_scheme: str) -> Style:
@@ -207,7 +215,7 @@ def _get_file(function: Callable[..., Any], skipped_paths: list[Path] = None) ->
         hasattr(function, "__wrapped__")
         and Path(inspect.getsourcefile(function)) in skipped_paths
     ):
-        return _get_file(function.__wrapped__)  # type: ignore[attr-defined]
+        return _get_file(function.__wrapped__)
     else:
         return Path(inspect.getsourcefile(function))
 
@@ -217,7 +225,7 @@ def _get_source_lines(function: Callable[..., Any]) -> int:
     if isinstance(function, functools.partial):
         return _get_source_lines(function.func)
     elif hasattr(function, "__wrapped__"):
-        return _get_source_lines(function.__wrapped__)  # type: ignore[attr-defined]
+        return _get_source_lines(function.__wrapped__)
     else:
         return inspect.getsourcelines(function)[1]
 
@@ -248,7 +256,7 @@ def create_summary_panel(
         Padding(str(n_total), pad=_HORIZONTAL_PADDING),
         Padding(description_total, pad=_HORIZONTAL_PADDING),
         Padding("", pad=_HORIZONTAL_PADDING),
-        style="#ffffff",
+        style="#f2f2f2",
     )
     for outcome, value in counts.items():
         if value:
@@ -268,7 +276,7 @@ def create_summary_panel(
 
     panel = Panel(
         grid,
-        title="[bold #ffffff]Summary[/bold #ffffff]",
+        title="[bold #f2f2f2]Summary[/]",
         expand=False,
         style="none",
         border_style=outcome_enum.FAIL.style
